@@ -5,8 +5,17 @@ macro_rules! err {
     }};
 }
 
-macro_rules! yaml_bad {
-    [] => { &yaml_rust::Yaml::BadValue };
+macro_rules! get_archive {
+    () => {{
+        use std::env::current_exe;
+        let mut path = current_exe()?.with_file_name(ARCHIVE);
+        path.set_extension("zip");
+        path
+    }};
+}
+
+macro_rules! yaml_null {
+    [] => { &yaml_rust::Yaml::Null };
 }
 
 macro_rules! yaml_bool {
@@ -22,12 +31,14 @@ macro_rules! yaml_vec {
     [$($v:tt)?] => { &yaml_rust::Yaml::Array(vec![$($v)?]) };
 }
 
+pub use crate::blank::*;
 pub use crate::fmt::*;
 pub use crate::loader::*;
 pub use crate::pack::*;
 pub use crate::serve::*;
 pub use crate::update::*;
 
+mod blank;
 mod content;
 mod fmt;
 mod loader;
